Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
// AppSettings is a global variable that holds the application settings
AppSettings = defaultSettings()
)
Functions ¶
func LoadFromEnvironment ¶
func LoadFromEnvironment() error
LoadFromEnvironment will try to load all the options from environment variables. It will return an error if the required options are not available. The required environment variables are:
UPSTREAM_TOKENINFO_URL
OPENID_PROVIDER_CONFIGURATION_URL
REVOCATION_PROVIDER_URL
The remaining options have sane defaults and are not mandatory
Types ¶
type Settings ¶
type Settings struct {
ListenAddress string
MetricsListenAddress string
UpstreamTokenInfoURL *url.URL
UpstreamTimeout time.Duration
UpstreamCacheMaxSize int64
UpstreamCacheTTL time.Duration
OpenIDProviderConfigurationURL *url.URL
OpenIDProviderRefreshInterval time.Duration
HTTPClientTimeout time.Duration
HTTPClientTLSTimeout time.Duration
RevocationCacheTTL time.Duration
RevocationProviderRefreshInterval time.Duration
RevocationRefreshTolerance time.Duration
RevocationProviderUrl *url.URL
HashingSalt string
JwtProcessors map[string]processor.JwtProcessor
}
The Settings type contains the application configurable options
Click to show internal directories.
Click to hide internal directories.